@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
-from . import data
-from . import metrics
-from . import utils
+import data
+import metrics
+import utils
 
 __all__ = ('__version__', 'data', 'metrics', 'utils')
